from setuptools import setup, find_packages

setup(
    name="sunil_math_calculator",
    version="0.1",
    author="Sunil Chandra",
    description="A simple calculator package",
    packages=find_packages(),
)